@@ -13,7 +13,10 @@
 # limitations under the License.
 
 from click.testing import CliRunner
-from source.ah import cli, list_cluster, add_cluster, login
+from source.ah import cli
+from source.cluster.commands import list_cluster
+from source.cluster.commands import add_cluster
+from source.cluster.commands import login
 from tests.properties import Properties
 import json
 
@@ -26,22 +29,23 @@ def test_cluster_tags_correct():
     assert "https://staging-qa-integration-001.ean.io/" in result.output
 
 
-def test_cluster_help():
+def test_cli_help():
     str_tags = "--help  Show this message and exit."
     runner = CliRunner()
     result = runner.invoke(cli, '--help')
+
     assert result.output.find(str_tags) != -1
 
 
 def test_cluster_add_help():
-    str_tags = "Create a new remote cluster"
+    str_tags = "Store a new cluster information"
     runner = CliRunner()
     result = runner.invoke(add_cluster, '--help')
     assert result.output.find(str_tags) != -1
 
 
 def test_cluster_list_help():
-    str_tags = "List all available clusters"
+    str_tags = "List all the cluster the user has stored on this machine"
     runner = CliRunner()
     result = runner.invoke(list_cluster, '--help')
     assert result.output.find(str_tags) != -1
